@@ -493,7 +493,8 @@ int main _P2((argc, argv), int argc, char ** argv)
     /* this is the last time we try anything [unix time] */
     end_time = time(NULL) + c_int(max_retry_time);
 
-    detach_tty();
+    if ( !c_bool(nodetach) )
+	detach_tty();
 
     /* give init time to restart mgetty (otherwise, "find_device"
      * will complain). This *IS* a race condition :-(
@@ -501,8 +502,8 @@ int main _P2((argc, argv), int argc, char ** argv)
      * Also, wait for a randomized time, to confuse potential attackers.
      */
     srand((unsigned)time(NULL));
-    i = c_int(delay) + (c_int(delay_rand)>0) ? rand()%c_int(delay_rand)
-					     : rand()%5;
+    i = c_int(delay) + ( (c_int(delay_rand)>0) ? rand()%c_int(delay_rand)
+					       : rand()%5 );
     if (i<4) i=4;
     lprintf( L_NOISE, "delaying %d seconds", i );
     sleep(i);
