@@ -1,4 +1,4 @@
-#ident "@(#)cnd.c	$Id: cnd.c,v 4.7 1998/03/26 09:17:38 gert Exp $ Copyright (c) 1993 Gert Doering/Chris Lewis"
+#ident "@(#)cnd.c	$Id: cnd.c,v 4.12 1998/06/19 20:29:48 gert Exp $ Copyright (c) 1993 Gert Doering/Chris Lewis"
 
 #include <stdio.h>
 #include <string.h>
@@ -15,6 +15,7 @@ char *Connect = "";
 char *CallerId = "none";
 char *CallTime = "";
 char *CallName = "";
+char *CalledNr = "";			/* dialed number [ISDN MSN] */
 /* the next few are for Rockwell */
 char *CallDate = "";
 char *CallMsg1 = "";
@@ -64,6 +65,9 @@ struct cndtable cndtable[] =
     /* yet another incompatible modem... */
     {"CALLER'S NUMBER: ",	&CallerId},
 
+    /* Kortex Adaptix 56000 (Quercia Michel, quercia@cal.enst.fr) */
+    {"NBR=",			&CallerId},
+
     {NULL}
 };
     
@@ -222,3 +226,31 @@ int cndlookup _P0 (void)
 #endif
     return(match);
 }
+
+/* check Caller ID via external program call */
+int cnd_call _P3((name, tty, dist_ring),
+		 char * name, char * tty, int dist_ring )
+{
+    char * program;
+    int rc;
+
+    program = malloc( strlen(name) + strlen(tty) + 
+		      strlen( CallerId ) + strlen( CalledNr ) +
+		      sizeof( CONSOLE ) + 50 );
+    if ( program == NULL )
+	    { lprintf( L_ERROR, "cnd_call: can't malloc" ); return 0; }
+
+    sprintf( program, "%s %s '%s' '%s' %d '%s' >%s 2>&1 </dev/null", name,
+		      tty, CallerId, CallName, dist_ring, CalledNr, CONSOLE );
+    lprintf( L_NOISE, "CND: program \"%s\"", program );
+
+    rc = system(program);
+
+    if ( rc < 0 )
+    { lprintf( L_ERROR, "cnd_call: system failed" ); free(program); return 0; }
+
+    lprintf( L_NOISE, "CND: rc=0x%x", rc );
+    free(program);
+
+    return rc>>8;
+}
