@@ -1,4 +1,4 @@
-#ident "$Id: conf_mg.c,v 4.5 1997/12/05 23:44:54 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: conf_mg.c,v 4.9 1998/08/03 20:01:45 gert Exp $ Copyright (c) Gert Doering"
 
 /* conf_mg.c
  *
@@ -78,10 +78,13 @@ struct conf_data_mgetty c = {
 	{ "modem-quirks", {0}, CT_INT, C_EMPTY },
 	{ "init-chat", {0}, CT_CHAT, C_EMPTY },
 	{ "force-init-chat", {0}, CT_CHAT, C_EMPTY },
+	{ "post-init-chat", {0}, CT_CHAT, C_EMPTY },
 
 	{ "modem-check-time", {MODEM_CHECK_TIME}, CT_INT, C_PRESET },
 	{ "rings", {1}, CT_INT, C_PRESET },
+	{ "msn-list", {(p_int) NULL}, CT_CHAT, C_EMPTY },
 	{ "get-cnd-chat", {0}, CT_CHAT, C_EMPTY },
+	{ "cnd-program", {(p_int) NULL}, CT_STRING, C_EMPTY },
 	{ "answer-chat", {0}, CT_CHAT, C_EMPTY },
 	{ "answer-chat-timeout", {80}, CT_INT, C_PRESET },
 	{ "autobauding", {FALSE}, CT_BOOL, C_PRESET },
@@ -101,6 +104,8 @@ struct conf_data_mgetty c = {
 	{ "fido-send-emsi", {TRUE}, CT_BOOL, C_PRESET },
 
 	{ "fax-id", {(p_int)FAX_STATION_ID}, CT_STRING, C_PRESET },
+	{ "fax-min-speed", {0}, CT_INT, C_PRESET },
+	{ "fax-max-speed", {14400}, CT_INT, C_PRESET },
 	{ "fax-server-file", {0}, CT_STRING, C_EMPTY },
 	{ "diskspace", {MINFREESPACE}, CT_INT, C_PRESET },
 #ifdef MAIL_TO
