@@ -1,4 +1,4 @@
-#ident "$Id: conf_mg.h,v 4.2 1997/12/05 23:44:56 gert Exp $ Copyright (c) 1994 Gert Doering"
+#ident "$Id: conf_mg.h,v 4.6 1998/08/03 20:01:46 gert Exp $ Copyright (c) 1994 Gert Doering"
 
 /* all (dynamic) mgetty configuration is contained in this structure.
  * It is initialized and loaded in conf_mg.c and accessed from mgetty.c
@@ -23,10 +23,13 @@ extern struct conf_data_mgetty {
 	modem_quirks,				/* strange behaviourisms */
 	init_chat,				/* modem initialization */
 	force_init_chat,			/* for stubborn modems */
+	post_init_chat,				/* for forgetful modems */
 
 	modem_check_time,			/* modem still alive? */
 	rings_wanted,				/* number of RINGs */
+	msn_list,				/* ISDN MSNs (dist.ring) */
 	getcnd_chat,				/* get caller ID (for ELINK)*/
+	cnd_program,				/* accept caller? */
 	answer_chat,				/* ATA...CONNECT...""...\n */
 	answer_chat_timeout,			/* longer as S7! */
 	autobauding,
@@ -42,6 +45,8 @@ extern struct conf_data_mgetty {
 	do_send_emsi,				/* send EMSI_REQ string */
 
 	station_id,				/* local fax station ID */
+	fax_min_speed,				/* minimum fax speed */
+	fax_max_speed,				/* maximum fax sped */
 	fax_server_file,			/* fax to send upon poll */
 	diskspace,				/* min. free disk space */
 	notify_mail,				/* fax mail goes to... */
