@@ -1,4 +1,4 @@
-#ident "$Id: conf_sf.c,v 4.8 1997/12/05 23:44:56 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: conf_sf.c,v 4.11 1998/07/05 20:31:43 gert Exp $ Copyright (c) Gert Doering"
 
 /* conf_sf.c
  *
@@ -42,15 +42,13 @@ struct conf_data_sendfax c = {
 	{ "speed", {FAX_SEND_BAUD}, CT_INT, C_PRESET },
 	{ "switchbd", {FAX_SEND_SWITCHBD}, CT_INT, C_PRESET },
 	{ "open-delay",	{0}, CT_INT, C_EMPTY },
-#ifdef FAX_SEND_IGNORE_CARRIER
 	{ "ignore-carrier", {TRUE }, CT_BOOL, C_PRESET },
-#else
-	{ "ignore-carrier", {FALSE}, CT_BOOL, C_PRESET },
-#endif
 	{ "dial-prefix", {(p_int) FAX_DIAL_PREFIX}, CT_STRING, C_PRESET },
 	{ "fax-id", {(p_int)FAX_STATION_ID}, CT_STRING, C_PRESET },
 	{ "poll-dir", {(p_int)"."}, CT_STRING, C_PRESET },
 	{ "normal-res", {0}, CT_BOOL, C_PRESET },
+	{ "fax-min-speed", {0}, CT_INT, C_PRESET },
+	{ "fax-max-speed", {14400}, CT_INT, C_PRESET },
 	{ "debug", {LOG_LEVEL}, CT_INT, C_PRESET },
 	{ "verbose", {FALSE}, CT_BOOL, C_PRESET },
 	{ "" /* polling */, {FALSE}, CT_BOOL, C_PRESET },
@@ -89,7 +87,7 @@ conf_data c_a[2];
     }
 
     /* get command line arguments */
-    while ((opt = getopt(argc, argv, "d:vx:ph:l:nm:SC:I:rA:D:V")) != EOF)
+    while ((opt = getopt(argc, argv, "d:vx:ph:l:nm:SC:I:rA:D:M:V")) != EOF)
     {
 	switch (opt) {
 	  case 'd':	/* set target directory for polling */
@@ -142,10 +140,13 @@ conf_data c_a[2];
 	  case 'D':
 	    conf_set_string( &c.dial_prefix, optarg );
 	    break;
+	  case 'M':	/* set max. fax speed */
+	    conf_set_int( &c.fax_max_speed, atoi(optarg) );
+	    break;
 	  case 'V':
 	    printf("\nmgetty+sendfax by Gert Doering\n%s\n\n",
 		    mgetty_version);
-	    printf("log file written to '%s'\n\n", FAX_LOG );
+	    printf("log file written to '%s'\n", FAX_LOG );
 #ifdef SENDFAX_CONFIG
             printf("config file read from '%s'\n\n", 
 			makepath( SENDFAX_CONFIG, CONFDIR ));
