@@ -1,4 +1,4 @@
-#ident "@(#)fax_lib.h	4.2 97/06/08 Copyright (c) Gert Doering"
+#ident "$Id: fax_lib.h,v 4.8 1997/12/09 10:58:28 gert Exp $ Copyright (c) Gert Doering"
 
 
 /* fax_lib.h
@@ -10,7 +10,13 @@
 
 /* data types + variables */
 
-typedef enum { Mt_unknown, Mt_data, Mt_class2, Mt_class2_0 } Modem_type;
+typedef enum { Mt_unknown, Mt_data, 
+		Mt_class1,	/* TIA/EIA 578 standard */
+		Mt_class1_0,	/* ITU T.31 standard */
+		Mt_class2, 	/* SP-2388 / EIA 592 drafts */
+		Mt_class2_0,	/* TIA/EIA 592 standard */
+		Mt_class2_1	/* ITU T.32 standard */
+		} Modem_type;
 extern Modem_type modem_type;
 
 typedef enum { pp_mps, pp_eom, pp_eop,
@@ -34,6 +40,7 @@ int fax_set_l_id _PROTO(( int fd, char * fax_id ));
 int fax_set_fdcc _PROTO(( int fd, int fine, int maxsp, int minsp ));
 int fax_set_bor  _PROTO(( int fd, int bit_order ));
 int fax_set_flowcontrol _PROTO(( int fd, int hw_flow ));
+int mdm_identify _PROTO(( int fd ));
 
 #ifdef __TIO_H__
 int fax_send_page _PROTO(( char * g3_file, int * bytes_sent, TIO * tio,
@@ -91,3 +98,6 @@ extern	int	modem_quirks;			/* modem specials */
 
 #define MQ_NEED2	0x01	/* must be in +FCLASS=2 for +FAA=1 to work */
 #define MQ_FBOR_OK	0x02	/* +FBOR implemented correctly (Multitech) */
+#define MQ_NO_LQC	0x04	/* +FPS:x,lc,blc can't be trusted */
+#define MQ_NO_XON	0x08	/* do not wait for XON char when sending */
+#define MQ_USR_FMINSP	0x20	/* USR: +FCC=1,<max> sets MIN speed instead */
