@@ -1,4 +1,4 @@
-#ident "$Id: faxlib.c,v 4.34 1998/02/12 08:25:32 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxlib.c,v 4.36 1998/06/20 15:58:13 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxlib.c
  *
@@ -668,6 +668,11 @@ int mdm_identify _P1( (fd), int fd )
 	    lprintf( L_MESG, "Discovery 2400 AM detected" );
 	    modem_type=Mt_data;
 	    break;
+	  case 288: /* Fred Wendorf */
+	    lprintf( L_MESG, "Trust Communicator 28 K8 detected" );
+	    modem_type=Mt_class2;
+	    modem_quirks |= MQ_NEED2;
+	    break;
 	  case 641: /* sure? */
 	    lprintf( L_MESG, "ELSA MicroLink ISDN/TLpro detected" );
 	    modem_type=Mt_data;
@@ -713,6 +718,9 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_quirks |= MQ_NO_LQC;		/* +FPS: broken */
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
 	    break;
+	  case 336:				/* one report only */
+	    lprintf( L_MESG, "could be a CompuTime RalleyCom 336" );
+	    break;
 	  default:
 	    lprintf( L_MESG, "unknown numerical modem id %d", mid );
 	    break;
