@@ -1,4 +1,4 @@
-#ident "$Id: mgetty.c,v 4.12 1998/04/02 17:02:41 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.c,v 4.23 1998/09/01 11:14:45 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.c
  *
@@ -36,12 +36,6 @@
 # endif
 #endif
 
-#ifdef DIST_RING
-char *	ring_chat_seq[] = { "RING\r", NULL };
-#else
-char *	ring_chat_seq[] = { "RING", NULL };
-#endif
-
 /* how much time may pass between two RINGs until mgetty goes into */
 /* "waiting" state again */
 int     ring_chat_timeout = 10;
@@ -58,24 +52,6 @@ chat_action_t	ring_chat_actions[] = { { "CONNECT",	A_CONN },
 					{ "+FHNG:",	A_FAIL },
 #ifdef VOICE
 					{ "VCON",       A_VCON },
-#endif
-#ifdef DIST_RING
-		/* ZyXEL */		{ "RING 1",	A_RING1 },
-					{ "RING 2",	A_RING2 },
-					{ "RING 3",	A_RING3 },
-					{ "RING 4",	A_RING4 },
-					{ "RING 5",	A_RING5 },
-		/* USR */		{ "RING A",	A_RING1 },
-					{ "RING B",	A_RING2 },
-					{ "RING C",	A_RING3 },
-					{ "RING D",	A_RING4 },
-					{ "RING E",	A_RING5 },
-		/* Hayes Acura */	{ "RING U",	A_RING5 },
-		/* Supra */		{ "RING1",	A_RING1 },
-					{ "RING2",	A_RING2 },
-					{ "RING3",	A_RING3 },
-					{ "RING4",	A_RING4 },
-					{ "RING5",	A_RING5 },
 #endif
 					{ NULL,		A_FAIL } };
 
@@ -160,6 +136,7 @@ enum mgetty_States
        St_dialout,			/* parallel dialout, wait for
 					   lockfile to disappear */
        St_get_login,			/* prompt "login:", call login() */
+       St_callback_login,		/* ditto, but after callback */
        St_incoming_fax			/* +FCON detected */
    } mgetty_state = St_unknown;
 
@@ -169,6 +146,7 @@ static RETSIGTYPE sig_new_config(SIG_HDLR_ARGS)
     signal( SIGUSR2, sig_new_config );
     if ( mgetty_state != St_answer_phone &&
 	 mgetty_state != St_get_login &&
+	 mgetty_state != St_callback_login &&
 	 mgetty_state != St_incoming_fax )
     {
 	lprintf( L_AUDIT, "exit dev=%s, pid=%d, got signal USR2, exiting",
@@ -225,7 +203,7 @@ enum mgetty_States st_sig_callback _P2( (pid, devname),
     }
 
     /* now give user a login prompt! */
-    return St_get_login;
+    return St_callback_login;
 }
 
 /* line locked, parallel dialout in process.
@@ -296,6 +274,7 @@ int main _P2((argc, argv), int argc, char ** argv)
     action_t	what_action;
     int		rings_wanted;
     int		rings = 0;
+    int		dist_ring = 0;		/* type of RING detected */
 
 #if defined(_3B1_) || defined(MEIBE) || defined(sysV68)
     extern struct passwd *getpwuid(), *getpwnam();
@@ -494,7 +473,8 @@ int main _P2((argc, argv), int argc, char ** argv)
 	if ( ( ! c_bool(data_only) ) &&
 	     strcmp( c_string(modem_type), "data" ) != 0 && 
 	     mg_init_fax( STDIN, c_string(modem_type),
-			  c_string(station_id), c_bool(fax_only) ) == SUCCESS )
+			  c_string(station_id), c_bool(fax_only),
+			  c_int(fax_max_speed) ) == SUCCESS )
 	{
 	    /* initialize fax polling server (only if faxmodem) */
 	    if ( c_isset(fax_server_file) )
@@ -516,6 +496,15 @@ int main _P2((argc, argv), int argc, char ** argv)
     }
 #endif /* VOICE */
 
+	/* some modems forget some of their settings during fax/voice
+	 * initialization -- use this as 'last chance' to set those things
+	 * [don't care for errors here]
+	 */
+	if ( c_isset( post_init_chat ) )
+	{
+	    lprintf( L_NOISE, "running post_init_chat" );
+	    do_chat( STDIN, c_chat(post_init_chat), NULL, NULL, 10, TRUE );
+	}
     }
 
     /* wait .3s for line to clear (some modems send a \n after "OK",
@@ -538,7 +527,8 @@ int main _P2((argc, argv), int argc, char ** argv)
     /* sleep... waiting for activity */
     mgetty_state = St_waiting;
 
-    while ( mgetty_state != St_get_login )
+    while ( mgetty_state != St_get_login && 
+	    mgetty_state != St_callback_login )
     {
 	switch (mgetty_state)	/* state machine */
 	{
@@ -547,7 +537,7 @@ int main _P2((argc, argv), int argc, char ** argv)
 	     * /etc/nologin file), do some cleanups, and go back to
 	     * field one: St_waiting
 	     */
-	    CallTime = CallName = "";			/* dirty */
+	    CallTime = CallName = CalledNr = "";	/* dirty */
 	    CallerId = "none";
 	    clean_line( STDIN, 3);			/* let line settle */
 	    rmlocks();
@@ -577,10 +567,16 @@ int main _P2((argc, argv), int argc, char ** argv)
 		     ! c_bool(direct_line) && ! virtual_ring )
 		{
 		    /* no activity - is the modem alive or dead? */
+		    log_close();
 		    mgetty_state = St_check_modem;
 		    break;
 		}
 	    }
+
+	    /* close (and reopen) log file, to make sure it hasn't been
+	     * moved away while sleeping and waiting for 'activity'
+	     */
+	    log_close();
 	
 	    /* check for LOCK files, if there are none, grab line and lock it
 	     */
@@ -652,8 +648,8 @@ int main _P2((argc, argv), int argc, char ** argv)
 
 	    /* while phone is ringing... */
 	    
-	    while ( do_chat( STDIN, ring_chat_seq, ring_chat_actions,
-			      &what_action, 10, TRUE ) == SUCCESS )
+	    while( wait_for_ring( STDIN, NULL, 10, ring_chat_actions, 
+				  &what_action, &dist_ring ) == SUCCESS )
 	    {
 		rings++;
 		if ( access( buf, F_OK ) != 0 ||	/* removed? */
@@ -706,12 +702,14 @@ int main _P2((argc, argv), int argc, char ** argv)
 		break;
 	    }
 
+	    dist_ring=0;		/* yet unspecified RING type */
+
 	    if ( c_bool(ringback) )	/* don't pick up on first call */
 	    {
 		int n = 0;
 		
-		while ( do_chat( STDIN, ring_chat_seq, ring_chat_actions,
-				 &what_action, 17, TRUE ) == SUCCESS &&
+		while( wait_for_ring( STDIN, NULL, 17, ring_chat_actions, 
+				      &what_action, &dist_ring ) == SUCCESS &&
 		        ! virtual_ring )
 		{ n++; }
 		
@@ -731,15 +729,14 @@ int main _P2((argc, argv), int argc, char ** argv)
 
 	    while ( rings < rings_wanted )
 	    {
-		if ( do_chat( STDIN, ring_chat_seq, ring_chat_actions,
-			      &what_action,
-			      ( c_bool(ringback) && rings == 0 )
-				    ? c_int(ringback_time) : ring_chat_timeout,
-			      TRUE ) == FAIL
-#ifdef DIST_RING
-		    && ( what_action < A_RING1 || what_action > A_RING5 )
-#endif
-		   ) break;
+		if ( wait_for_ring( STDIN, c_chat(msn_list), 
+			  ( c_bool(ringback) && rings == 0 )
+				? c_int(ringback_time) : ring_chat_timeout,
+			  ring_chat_actions, &what_action, 
+			  &dist_ring ) == FAIL)
+		{
+		    break;		/* ringing stopped, or "action" */
+		}
 		rings++;
 	    }
 
@@ -803,7 +800,11 @@ Ring_got_action:
 		do_chat( STDIN, c_chat(getcnd_chat), NULL, NULL, 10, TRUE );
 	    }
 		
-	    if ( !cndlookup() )
+	    /* Check Caller ID.  Static table first, then cnd-program.  */
+
+	    if ( !cndlookup() ||
+	         ( c_isset(cnd_program) &&
+		   cnd_call( c_string(cnd_program), Device, dist_ring ) == 1))
 	    {
 		lprintf( L_AUDIT, "denied caller dev=%s, pid=%d, caller='%s'",
 			 Device, getpid(), CallerId);
@@ -832,13 +833,12 @@ Ring_got_action:
 		/* The modem will be in voice mode when voice_answer is
 		   called. If the function returns, the modem is ready
 		   to be connected in DATA mode with ATA. */
-		
-		if ( vgetty_answer(rings, rings_wanted, what_action) ==
+
+		if ( vgetty_answer(rings, rings_wanted, dist_ring) ==
 		 VMA_CONNECT )
 		{
 		/* unexpected "CONNECT" -> jump to reading of login name
 		 */
-		    mg_get_ctty( STDIN, devname );
 		    mgetty_state = St_get_login; break;
 		};
 	    }
@@ -1055,7 +1055,7 @@ Ring_got_action:
 	}
 
 	/* hand off to login dispatcher (which will call /bin/login) */
-	login_dispatch( buf );
+	login_dispatch( buf, mgetty_state == St_callback_login? TRUE: FALSE);
 
 	/* doesn't return, if it does, something broke */
 	exit(FAIL);
