@@ -1,7 +1,7 @@
 #ifndef ___MGETTY_H
 #define ___MGETTY_H
 
-#ident "$Id: mgetty.h,v 4.6 1997/12/05 23:49:40 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.h,v 4.13 1998/09/11 10:45:07 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.h
  *
@@ -33,13 +33,13 @@
 
 /* defines for auto detection of incoming PPP calls (->PAP/CHAP) */
 
-#define PPP_FRAME           0x7e  /* PPP Framing character */
-#define PPP_STATION         0xff  /* "All Station" character */
-#define PPP_ESCAPE          0x7d  /* Escape Character */ 
-#define PPP_CONTROL         0x03  /* PPP Control Field */
-#define PPP_CONTROL_ESCAPED 0x23  /* PPP Control Field, escaped */
-#define PPP_LCP_HI          0xc0  /* LCP protocol - high byte */
-#define PPP_LCP_LOW         0x21  /* LCP protocol - low byte */
+#define PPP_FRAME	0x7e	/* PPP Framing character */
+#define PPP_STATION	0xff	/* "All Station" character */
+#define PPP_ESCAPE	0x7d	/* Escape Character */ 
+#define PPP_CONTROL	0x03	/* PPP Control Field */
+#define PPP_LCP_HI	0xc0	/* LCP protocol - high byte */
+#define PPP_LCP_LOW	0x21	/* LCP protocol - low byte */
+#define PPP_UNESCAPE(c)	((c) ^ 0x20) /* un-escape character */
 
 /* stuff in logfile.c */
 
@@ -53,6 +53,7 @@
 
 void log_init_paths _PROTO(( char * program, char * path, char * infix ));
 void log_set_llevel _PROTO(( int level ));
+void log_close _PROTO((void));
 int lputc _PROTO(( int level, char ch ));
 int lputs _PROTO(( int level, char * s ));
 int lprintf _PROTO(());
@@ -92,6 +93,14 @@ int lprintf _PROTO(());
 #define USE_SELECT
 #endif
 
+/* SunOS4 does not have memmove, but bcopy handles overlapping copies
+ * as well. Watch out for src/dst argument order!
+ */
+
+#if defined(sunos4) || defined(NEED_MEMMOVE)
+# define memmove(dst, src, len) bcopy(src, dst, len)
+#endif
+
 /* these definitions specify the return value type and the arguments
  * for signal handler functions - if your compiler barfs, change them
  */
@@ -183,6 +192,11 @@ int	do_chat _PROTO(( int filedesc, char * expect_send[],
 int	do_chat_send _PROTO(( int filedesc, char * send_str_with_esc ));
 int	clean_line _PROTO(( int filedesc, int tenths ));
 
+/* ring.c */
+int	wait_for_ring _PROTO(( int filedesc, char ** msn_list, int timeout, 
+			       chat_action_t actions[], action_t * action,
+			       int * dist_ring_number ));
+
 /* do_stat.c */
 void	get_statistics _PROTO(( int filedesc, char ** chat, char * file ));
 
@@ -213,8 +227,8 @@ extern	int modem_quirks;
 
 /* initialization stuff: mg_m_init.c */
 int	mg_init_data  _PROTO(( int fd, char * chat_seq[], char * force_seq[]));
-int	mg_init_fax   _PROTO(( int fd, char * mclass,
-			       char * fax_id, boolean fax_only ));
+int	mg_init_fax   _PROTO(( int fd, char * mclass, char * fax_id, 
+			       boolean fax_only, int fax_max_speed ));
 int 	mg_init_voice _PROTO(( int fd ));
 void	faxpoll_server_init _PROTO(( int fd, char * fax_server_file ));
 int	mg_open_device _PROTO(( char * devname, boolean blocking ));
@@ -239,7 +253,7 @@ char *	ln_escape_prompt _PROTO(( char * prompt ));
 void	set_env_var _PROTO(( char * var, char * string ));
 
 /* login stuff */
-void login_dispatch _PROTO(( char * user ));
+void login_dispatch _PROTO(( char * user, boolean is_callback ));
 
 /* how long should I wait for a string from modem */
 #define FAX_RESPONSE_TIMEOUT	120
@@ -252,9 +266,11 @@ extern char *Connect;
 extern char *CallerId;
 extern char *CallTime;
 extern char *CallName;
+extern char *CalledNr;
 
 void cndfind _PROTO((char *str));
 int cndlookup _PROTO((void));
+int cnd_call _PROTO((char *name, char *tty, int dist_ring ));
 
 /* disk statistics retrieval in getdisk.c */
 
