@@ -1,4 +1,4 @@
-#ident "$Id: sendfax.c,v 4.13 1998/01/01 20:26:27 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: sendfax.c,v 4.15 1998/07/02 09:23:49 gert Exp $ Copyright (c) Gert Doering"
 
 /* sendfax.c
  *
@@ -48,7 +48,10 @@ void exit_usage _P2( (program, msg ),
 		     char * program, char * msg )
 {
     if ( msg != NULL )
+    {
+	lprintf( L_ERROR, "exit_usage: %s", msg );
         fprintf( stderr, "%s: %s\n", program, msg );
+    }
     
     fprintf( stderr,
 	     "usage: %s [options] <fax-number> <page(s) in g3-format>\n", program);
@@ -459,7 +462,7 @@ int main _P2( (argc, argv),
     /* set desired resolution, maximum and minimum bit rate */
 
     /* FIXME: ask modem if it can do 14400 bps / fine res. at all */
-    fax_set_fdcc( fd, !c_bool(normal_res), 14400, 0 );
+    fax_set_fdcc( fd, !c_bool(normal_res), c_int(fax_max_speed), 0 );
 
 #if REVERSE
     fax_set_bor( fd, 0 );
