@@ -5,7 +5,7 @@
  * follow the IS-101 interim standard for voice modems. Since the commands
  * are set in the modem structure, it should be quite generic.
  *
- * $Id: IS_101.c,v 1.3 1998/03/25 23:05:34 marc Exp $
+ * $Id: IS_101.c,v 1.5 1998/09/09 21:07:18 gert Exp $
  *
  */
 
@@ -97,7 +97,7 @@ int IS_101_dial(char *number)
                if (voice_read(buffer) != OK)
                     return(FAIL);
 
-               result = voice_analyze(buffer, command);
+               result = voice_analyze(buffer, command, TRUE);
 
                switch (result)
                     {
@@ -797,6 +797,9 @@ int IS_101_switch_to_data_fax(char *mode)
       VMA_USER)
           return(FAIL);
 
+     if (voice_command("AT", "OK") != VMA_USER_1)
+          return(FAIL);
+
      return(OK);
      }
 
@@ -810,6 +813,9 @@ int IS_101_voice_mode_off(void)
       VMA_USER)
           return(FAIL);
 
+     if (voice_command("AT", "OK") != VMA_USER_1)
+          return(FAIL);
+
      return(OK);
      }
 
@@ -840,6 +846,9 @@ int IS_101_voice_mode_on(void)
       VMA_USER)
           return(FAIL);
 
+     if (voice_command("AT", "OK") != VMA_USER_1)
+          return(FAIL);
+
      return(OK);
      }
 
